var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/schema-utils.ts
import Ajv from "ajv";
import addTypeofKeyword from "ajv-keywords/keywords/typeof.js";
var ajv = new Ajv();
addTypeofKeyword(ajv);
var ajvDefaults = new Ajv({
  useDefaults: true
});
function validateSchema(schema) {
  const isSchemaValid = ajv.validateSchema(schema);
  return {
    ok: isSchemaValid,
    message: isSchemaValid ? "" : `Schema itself is not valid. ${ajv.errorsText()}`
  };
}
__name(validateSchema, "validateSchema");
function validateSchemaAndAssignDefaults(schema, data) {
  const { ok, message } = validateSchema(schema);
  if (!ok) {
    return {
      ok: false,
      message,
      data
    };
  }
  const newData = { ...data };
  const isValid = !!ajvDefaults.validate(schema, newData);
  return {
    ok: isValid,
    message: isValid ? "" : ajvDefaults.errorsText(),
    data: newData
  };
}
__name(validateSchemaAndAssignDefaults, "validateSchemaAndAssignDefaults");
function validateDataAgainstSchema(schema, data) {
  const { ok, message } = validateSchema(schema);
  if (!ok) {
    return {
      ok: false,
      message
    };
  }
  const isValid = !!ajv.validate(schema, data);
  return {
    ok: isValid,
    message: isValid ? "" : ajv.errorsText(),
    errors: isValid ? [] : ajv.errors
  };
}
__name(validateDataAgainstSchema, "validateDataAgainstSchema");
export {
  ajv,
  validateDataAgainstSchema,
  validateSchema,
  validateSchemaAndAssignDefaults
};
//# sourceMappingURL=schema-utils.mjs.map